==> dev-plugin-android-5.1.3-sources.jar: com/zoyi/channel/plugin/android/model/PushBotItem.java <==
package com.zoyi.channel.plugin.android.model;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.zoyi.channel.plugin.android.model.entity.Entity;
import com.zoyi.channel.plugin.android.model.entity.ProfileEntity;
import com.zoyi.channel.plugin.android.model.etc.PopupItem;
import com.zoyi.channel.plugin.android.model.rest.Bot;
import com.zoyi.channel.plugin.android.model.rest.PreviewThumb;
import com.zoyi.channel.plugin.android.model.rest.PushBot;
import com.zoyi.channel.plugin.android.model.rest.PushBotVariant;
import com.zoyi.channel.plugin.android.selector.BotSelector;
import com.zoyi.channel.plugin.android.util.TimeUtils;

/**
 * Created by jerry on 2018. 11. 23..
 */

public class PushBotItem implements Entity, PopupItem {

  @NonNull
  private PushBot pushBot;
  @Nullable
  private PushBotVariant pushBotVariant;
  private long createdAt;
  private int alertCount;
  private boolean removed;

  public static PushBotItem newInstance(@NonNull PushBot pushBot, @Nullable PushBotVariant pushBotVariant) {
    return new PushBotItem(pushBot, pushBotVariant);
  }

  private PushBotItem(@NonNull PushBot pushBot, @Nullable PushBotVariant pushBotVariant) {
    this.pushBot = pushBot;
    this.pushBotVariant = pushBotVariant;
    this.createdAt = TimeUtils.getCurrentTime();
    this.alertCount = 1;
    this.removed = false;
  }

  // PushBot variant id
  @NonNull
  @Override
  public String getId() {
    return pushBot.getId();
  }

  @Override
  public long getCreatedAt() {
    return createdAt;
  }

  @Nullable
  @Override
  public ProfileEntity getProfile() {
    if (pushBotVariant != null) {
      return BotSelector.getBotByName(pushBotVariant.getBotName());
    }

    return null;
  }

  @Nullable
  public String getBotId() {
    if (pushBotVariant != null) {
      Bot bot = BotSelector.getBotByName(pushBotVariant.getBotName());
      if (bot != null) {
        return bot.getId();
      }
    }
    return null;
  }

  @Nullable
  @Override
  public String getTitle() {
    if (pushBotVariant != null) {
      return pushBotVariant.getTitle();
    }

    return null;
  }

  @Nullable
  @Override
  public String getMessage() {
    if (pushBotVariant != null) {
      return pushBotVariant.getMessage();
    }

    return null;
  }

  @Nullable
  public String getButtonTitle() {
    if (pushBotVariant != null) {
      return pushBotVariant.getButtonTitle();
    }

    return null;
  }

  @Nullable
  public String getButtonRedirectUrl() {
    if (pushBotVariant != null) {
      return pushBotVariant.getButtonRedirectUrl();
    }

    return null;
  }

  @Nullable
  public PreviewThumb getImageThumb() {
    if (pushBotVariant != null) {
      return pushBotVariant.getImageThumb();
    }

    return null;
  }

  @Nullable
  public String getAttachment() {
    if (pushBotVariant != null) {
      return pushBotVariant.getAttachment();
    }

    return null;
  }

  @Nullable
  public String getImageRedirectUrl() {
    if (pushBotVariant != null) {
      return pushBotVariant.getImageRedirectUrl();
    }

    return null;
  }

  public int getAlertCount() {
    return alertCount;
  }

  public void read() {
    alertCount = 0;
  }

  public void remove() {
    alertCount = 0;
    removed = true;
  }

  public boolean shouldShowToList() {
    return pushBotVariant != null && !removed;
  }
}

==> dev-plugin-android-5.2.0.7-sources.jar: com/zoyi/channel/plugin/android/model/PushBotItem.java <==
package com.zoyi.channel.plugin.android.model;

import android.text.SpannableStringBuilder;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.zoyi.channel.plugin.android.model.entity.Entity;
import com.zoyi.channel.plugin.android.model.entity.ProfileEntity;
import com.zoyi.channel.plugin.android.model.etc.PopupItem;
import com.zoyi.channel.plugin.android.model.rest.Bot;
import com.zoyi.channel.plugin.android.model.rest.PreviewThumb;
import com.zoyi.channel.plugin.android.model.rest.PushBot;
import com.zoyi.channel.plugin.android.model.rest.PushBotVariant;
import com.zoyi.channel.plugin.android.selector.BotSelector;
import com.zoyi.channel.plugin.android.util.ParseUtils;
import com.zoyi.channel.plugin.android.util.TimeUtils;

/**
 * Created by jerry on 2018. 11. 23..
 */

public class PushBotItem implements Entity, PopupItem {

  @NonNull
  private PushBot pushBot;
  @Nullable
  private PushBotVariant pushBotVariant;
  private long createdAt;
  private int alertCount;
  private boolean removed;
  private SpannableStringBuilder formattedSpanMessage;

  public static PushBotItem newInstance(@NonNull PushBot pushBot, @Nullable PushBotVariant pushBotVariant) {
    return new PushBotItem(pushBot, pushBotVariant);
  }

  private PushBotItem(@NonNull PushBot pushBot, @Nullable PushBotVariant pushBotVariant) {
    this.pushBot = pushBot;
    this.pushBotVariant = pushBotVariant;
    this.createdAt = TimeUtils.getCurrentTime();
    this.alertCount = 1;
    this.removed = false;
    this.formattedSpanMessage = pushBotVariant != null ? ParseUtils.parseMessage(pushBotVariant.getMessage()) : new SpannableStringBuilder();
  }

  // PushBot variant id
  @NonNull
  @Override
  public String getId() {
    return pushBot.getId();
  }

  @Override
  public long getCreatedAt() {
    return createdAt;
  }

  @Nullable
  @Override
  public ProfileEntity getProfile() {
    if (pushBotVariant != null) {
      return BotSelector.getBotByName(pushBotVariant.getBotName());
    }

    return null;
  }

  @Nullable
  public String getBotId() {
    if (pushBotVariant != null) {
      Bot bot = BotSelector.getBotByName(pushBotVariant.getBotName());
      if (bot != null) {
        return bot.getId();
      }
    }
    return null;
  }

  @Nullable
  @Override
  public String getTitle() {
    if (pushBotVariant != null) {
      return pushBotVariant.getTitle();
    }

    return null;
  }

  @NonNull
  public String getMessage() {
    if (pushBotVariant != null) {
      return pushBotVariant.getMessage();
    }
    return "";
  }

  @NonNull
  @Override
  public SpannableStringBuilder getFormattedSpanMessage() {
    return formattedSpanMessage;
  }

  @Nullable
  public String getButtonTitle() {
    if (pushBotVariant != null) {
      return pushBotVariant.getButtonTitle();
    }

    return null;
  }

  @Nullable
  public String getButtonRedirectUrl() {
    if (pushBotVariant != null) {
      return pushBotVariant.getButtonRedirectUrl();
    }

    return null;
  }

  @Nullable
  public PreviewThumb getImageThumb() {
    if (pushBotVariant != null) {
      return pushBotVariant.getImageThumb();
    }

    return null;
  }

  @Nullable
  public String getAttachment() {
    if (pushBotVariant != null) {
      return pushBotVariant.getAttachment();
    }

    return null;
  }

  @Nullable
  public String getImageRedirectUrl() {
    if (pushBotVariant != null) {
      return pushBotVariant.getImageRedirectUrl();
    }

    return null;
  }

  public int getAlertCount() {
    return alertCount;
  }

  public void read() {
    alertCount = 0;
  }

  public void remove() {
    alertCount = 0;
    removed = true;
  }

  public boolean shouldShowToList() {
    return pushBotVariant != null && !removed;
  }
}
